@@ -30,11 +30,11 @@ class PARAMETROS:
         utl = U.LIB()
         try:
             dml =   f"""
-                    Insert into parametros
+                    Insert into {self._nome_tabela}
                                 (hash            
                                 ,hash_parent     
                                 ,num_ordem       
-                                ,des_familia     
+                                ,des_aplicacao     
                                 ,des_grupo       
                                 ,nom_parametro   
                                 ,nom_variavel    
@@ -50,7 +50,7 @@ class PARAMETROS:
                          values (:hash            
                                 ,:hash_parent     
                                 ,:num_ordem       
-                                ,:des_familia     
+                                ,:des_aplicacao     
                                 ,:des_grupo       
                                 ,:nom_parametro   
                                 ,:nom_variavel    
@@ -81,12 +81,12 @@ class PARAMETROS:
         function_name = inspect.stack()[0].function
         utl = U.LIB()
         try:
-            dml =  f"""UPDATE parametros SET %s = '%s'" %(.join({row.keys()}), .join({row.values()}))"""
+            dml =  f"""UPDATE {self._nome_tabela} SET %s = '%s'" %(.join({row.keys()}), .join({row.values()}))"""
             dml =   f"""
-                      Update parametros
+                      Update {self._nome_tabela}
                          set hash_parent        = :hash_parent          
                             ,num_ordem       	= :num_ordem       
-                            ,des_familia        = :des_familia     
+                            ,des_aplicacao        = :des_aplicacao     
                             ,des_grupo          = :des_grupo       
                             ,nom_parametro      = :nom_parametro   
                             ,nom_variavel       = :nom_variavel    
@@ -118,7 +118,7 @@ class PARAMETROS:
         utl = U.LIB()
         try:
             dml = f"""
-                      Delete from parametros                             
+                      Delete from {self._nome_tabela}                             
                        where hash = '{hash}'
                     """
             cur = self._cnn.cursor()
@@ -132,24 +132,24 @@ class PARAMETROS:
         finally:
             return msg
 
-    def FAMILIA_get(self, des_familia: list = None) -> dict:
+    def APLICACAO_get(self, des_aplicacao: list = None) -> dict:
         result, where_add = None, None
         try:
             utl = U.LIB()
             now = dt.datetime.now()
             separador_listas = "|"
-            if des_familia is None:
+            if des_aplicacao is None:
                 where_add = ""
             else:
-                where_add = f"""and p.des_familia in ('{"','".join(des_familia)}')"""
+                where_add = f"""and p.des_aplicacao in ('{"','".join(des_aplicacao)}')"""
             stmt =  f"""
                     Select *
-                      from parametros p
+                      from {self._nome_tabela} p
                      where dat_fim_vigencia is Null
                        and p.Dat_ini_vigencia <= '{now.strftime("%Y-%m-%d %H:%M:%S")}'
                        and p.flg_status = 'A'
                        {where_add}
-                     order by p.des_familia
+                     order by p.des_aplicacao
                     """
             cur = self._cnn.cursor()
             cur.execute(stmt)
@@ -163,6 +163,9 @@ class PARAMETROS:
                 #PAR.append(rs["nom_variavel"]}] = rs["val_parametro"]
             # avalidando os DataTypes para o ResultSet
             for row in rs:
+                if row["flg_encrypt"] == "S":
+                    token_string = self.VARIAVEL_get(["GERAL_TOKEN_BASE"])[0]
+                    row["val_parametro"] = utl.CRYPTOGRAPHY(word=row["val_parametro"], token=token_string)
                 if row["des_datatype"] == "DATETIME":
                     row["val_parametro"] = dt.datetime.strptime(utl.iif(row["val_parametro"] is None, "", row["val_parametro"]), "%Y-%m-%d %H:%M:%S")
                 elif row["des_datatype"] == "DATE":
@@ -171,20 +174,16 @@ class PARAMETROS:
                     row["val_parametro"] = dt.datetime.strptime(utl.iif(row["val_parametro"] is None, "", row["val_parametro"]), "%H:%M:%S")
                 elif row["des_datatype"] == "INTEGER":
                     row["val_parametro"] = int(utl.iif(row["val_parametro"] is None, "0", row["val_parametro"]))
-                elif row["des_datatype"] == "JSON":
-                    row["val_parametro"] = ast.literal_eval(row["val_parametro"])
                 elif row["des_datatype"] == "LIST":
                     row["val_parametro"] = row["val_parametro"].split(separador_listas)
-                elif row["des_datatype"] == "JSON/CRIPTOGRAFADO":
-                    token_string = self.VARIAVEL_get(["GERAL_TOKEN_BASE"])[0]
-                    json_string = utl.CRYPTOGRAPHY(word=row["val_parametro"], token=token_string)
-                    row["val_parametro"] = ast.literal_eval(json_string)
+                elif row["des_datatype"] == "JSON":
+                    row["val_parametro"] = ast.literal_eval(row["val_parametro"])
                 elif row["des_datatype"] == "LIST/JSON":
                     row["val_parametro"] = row["val_parametro"].split(separador_listas)
                     for i in range(len(row["val_parametro"])):
                         row["val_parametro"][i] = ast.literal_eval(row["val_parametro"][i])
         except Exception as error:
-            rs = f"""Falha na obtenção dos parametros para a FAMILIA de PARAMETROS: {des_familia}.\nErro: {error}"""
+            rs = f"""Falha na obtenção dos parametros para a FAMILIA de PARAMETROS: {des_aplicacao}.\nErro: {error}"""
         finally:
             return rs
 
@@ -198,7 +197,7 @@ class PARAMETROS:
                 where_add = f"""and p.nom_parametro in ('{"','".join(nom_parametro)}')"""
             stmt =  f"""
                     Select *
-                      from parametros p
+                      from {self._nome_tabela} p
                      where dat_fim_vigencia is Null
                        and p.Dat_ini_vigencia <= '{now.strftime("%Y-%m-%d %H:%M:%S")}'
                        and p.flg_status = 'A'
@@ -226,10 +225,10 @@ class PARAMETROS:
         finally:
             return values
 
-    def REPLICA_FAMILIA(self, des_familia_origem: str, des_familia_destino: str, commit: bool = True):
+    def REPLICA_APLICACAO(self, des_aplicacao_origem: str, des_aplicacao_destino: str, commit: bool = True):
         try:
             stmt = f"""Select *
-                         from parametros
+                         from {self._nome_tabela}
                         where nom_familia = :nom_familia  
                    """
             cur = self._cnn.cursor()
@@ -263,7 +262,7 @@ class PARAMETROS:
                     (hash               VARCHAR2(256)   PRIMARY KEY NOT NULL UNIQUE,
                     hash_parent         VARCHAR2(256),
                     num_ordem           VARCHAR (10)   DEFAULT ('0'),
-                    des_familia         VARCHAR (30)   NOT NULL,
+                    des_aplicacao         VARCHAR (30)   NOT NULL,
                     des_grupo           VARCHAR (30)   NOT NULL,
                     nom_parametro       VARCHAR2(256)  UNIQUE NOT NULL,
                     nom_variavel        VARCHAR2 (256) NOT NULL
@@ -292,7 +291,7 @@ class PARAMETROS:
                     (hash               TEXT    PRIMARY KEY NOT NULL UNIQUE,
                     hash_parent         TEXT,
                     num_ordem           VARCHAR (10)   DEFAULT ('0'),
-                    des_familia         VARCHAR (30),
+                    des_aplicacao         VARCHAR (30),
                     des_grupo           VARCHAR (30),
                     nom_parametro       TIME (256),
                     nom_variavel        VARCHAR2 (256) UNIQUE NOT NULL,
